pub enum TerminationReason {
User(&'static str),
Numerical(&'static str),
ResidualsZero,
Orthogonal,
Converged {
ftol: bool,
xtol: bool,
},
NoImprovementPossible(&'static str),
LostPatience,
NoParameters,
NoResiduals,
WrongDimensions(&'static str),
}Expand description
Reasons for terminating the minimization.
Variants
User(&'static str)
The residual or Jacobian computation was not successful, it returned None.
Numerical(&'static str)
Encountered NaN or $\pm\infty$.
ResidualsZero
The residuals are literally zero.
Orthogonal
The residuals vector and the Jacobian columns are almost orthogonal.
This is the gtol termination criterion.
Converged
The ftol or xtol criterion was fulfilled.
NoImprovementPossible(&'static str)
The bound for ftol, xtol or gtol was set so low that the
test passed with the machine epsilon but not with the actual
bound. This means you must increase the bound.
LostPatience
Maximum number of function evaluations was hit.
NoParameters
The number of parameters $n$ is zero.
NoResiduals
The number of residuals $m$ is zero.
WrongDimensions(&'static str)
The shape of the computed residuals or Jacobian is not correct.
Implementations
Sourceimpl TerminationReason
impl TerminationReason
Sourcepub fn was_successful(&self) -> bool
pub fn was_successful(&self) -> bool
Compute whether the outcome is considered successful.
This does not necessarily mean we have a minimizer. Some termination criteria are approximations for necessary optimality conditions or check limitations due to floating point arithmetic.
Sourcepub fn was_usage_issue(&self) -> bool
pub fn was_usage_issue(&self) -> bool
A fundamental assumptions was not met.
For example if the number of residuals changed.